@@ -12,9 +12,9 @@ def schedule(args):
     for role_name in roles_node.keys():
         subject_id = input('Please enter a user ID to fill the role of ' + role_name + ' for this session:')
         if subject_id != '':            
-            role_node[role_name].setValue(subject_id)
+            roles_node[role_name].setValue(subject_id)
         else:
-            role_node[role_name].setValue('?????')
+            roles_node[role_name].setValue('?????')
     schedule_org = None
     if os.path.isfile('session_schedule.org'):
         schedule_org = SAPOFTO.SAPOFTO('SCHEDULE',filename='session_schedule.org')
